Biomass composition
===================

Biomass composition can be represented in terms of cellulose, hemicellulose,
lignins, and extractives. If experimental data is not available, the
components of biomass can be estimated from the ultimate analysis using a
characterization method developed by Debiagi, Pecchi, Gentile, Frassoldati,
Cuoci, Faravelli, and Ranzi.

.. autofunction:: chemics.biocomp

.. autofunction:: chemics.plot_biocomp
